OC.L10N.register(
    "dav",
    {
    "Calendar" : "Egutegia",
    "Todos" : "Egitekoak",
    "Personal" : "Pertsonala",
    "{actor} created calendar {calendar}" : "{actor}-k sortutako egutegia: {calendar}",
    "You created calendar {calendar}" : "{calendar} egutegia sortu duzu",
    "{actor} deleted calendar {calendar}" : "{actor}-k  {calendar} egutegia borratu du",
    "You deleted calendar {calendar}" : "{calendar} egutegia borratu duzu",
    "{actor} updated calendar {calendar}" : "{actor} -k  {calendar} egutegia eguneratu du",
    "You updated calendar {calendar}" : "{calendar} egutegia eguneratu duzu ",
    "{actor} shared calendar {calendar} with you" : "{actor} -k zurekin {calendar} egutegia partekatu du",
    "You shared calendar {calendar} with {user}" : "{calendar} egutegia {user} erabiltzailearekin partekatu duzu",
    "{actor} shared calendar {calendar} with {user}" : "{actor} -k {calendar} egutegia {user}-rekin partekatu du",
    "{actor} unshared calendar {calendar} from you" : "{actor} zurekin partekatzen zuen {calendar} egutegia partekatzeari utzi dio",
    "You unshared calendar {calendar} from {user}" : "Partekatzen zenuen {calendar} egutegia {user} -rekin partekatzeari utzi diozu ",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} {user} erabiltzailearekin partekatzen zuen  {calendar} egutegia partekatzeari utzi dio",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} {calendar} egutegia partekatzeari utzi dio bere buruarekin",
    "You shared calendar {calendar} with group {group}" : "{calendar} egutegia {group} taldearekin partekatu duz",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} {group} taldearekin {calendar} egutegia partekatu du",
    "You unshared calendar {calendar} from group {group}" : "{group} taldearekin {calendar} egutegia partekatzeari utzi dio.",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}-rk  {group} taldearekin {calendar} egutegia partekatzeari utzi dio.",
    "{actor} created event {event} in calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera {calendar} egutegian sortu du.",
    "You created event {event} in calendar {calendar}" : "{calendar} egutegia {event} gertaera sortu duzu",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera {calendar} egutegitik ezabatu du",
    "You deleted event {event} from calendar {calendar}" : "{event} gertaera {calendar} egutegitik ezabatu duzu",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}-rek {event} gertaera {calendar} eguneratu du egutegian",
    "You updated event {event} in calendar {calendar}" : "{event} gertaera {calendar} egutegian eguneratu duzu ",
    "Busy" : "Lanpetua",
    "{actor} created todo {todo} in list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} ekintza sortu du.",
    "You created todo {todo} in list {calendar}" : "{calendar} zerrendan {todo} ekintza sortu duzu.",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} zeregina borratu du.",
    "You deleted todo {todo} from list {calendar}" : " {calendar} zerrendan {todo} zeregina borratu duzu.",
    "{actor} updated todo {todo} in list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} zeregina eguneratu du.",
    "You updated todo {todo} in list {calendar}" : "{calendar} zerrendan {todo} zeregina eguneratu duzu.",
    "{actor} solved todo {todo} in list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} zeregina bukatu du.",
    "You solved todo {todo} in list {calendar}" : " {calendar} zerrendan {todo} zeregina bukatu duzu.",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} zeregina birreki du.",
    "You reopened todo {todo} in list {calendar}" : "{calendar} zerrendan {todo} zeregina birreki duzu. ",
    "A <strong>calendar</strong> was modified" : "Egutegia aldatu da",
    "A calendar <strong>event</strong> was modified" : "Egutegiaren <strong>gertaera</strong> bat aldatu da",
    "A calendar <strong>todo</strong> was modified" : "Egutegiaren zeregin bat aldatu da",
    "Contact birthdays" : "Urtebetetze kontaktua",
    "Calendar:" : "Egutegia:",
    "Date:" : "Data:",
    "Where:" : "Non:",
    "Description:" : "Deskribapena:",
    "Untitled event" : "Izenik gabeko gertaera",
    "Calendar: %s" : "Egutegia: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Deskripzioa: %s",
    "Where: %s" : "Non: %s",
    "Invitation canceled" : "Gonbidapena ezeztatua",
    "Hello %s," : "Kaixo 1%s,",
    "Invitation updated" : "Gonbidapena eguneratu da",
    "When:" : "Noiz:",
    "Link:" : "Esteka:",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "More options …" : "Aukera gehiago …",
    "Contacts" : "Kontaktuak",
    "WebDAV" : "WebDAV",
    "Technical details" : "Xehetasun teknikoak",
    "Remote Address: %s" : "Urruneko helbidea: 1%s",
    "Request ID: %s" : "Eskatutako ID: 1%s",
    "Tentative" : "Behin behinekoa",
    "Save" : "Gorde",
    "Calendar server" : "Egutegi-zerbitzaria",
    "Send invitations to attendees" : "Gonbidatutakoei gonbidapenak bidali",
    "Please make sure to properly set up the email settings above." : "Mesedez, eposta ezarpenak ondo zehaztuta daudela ziurta ezazu"
},
"nplurals=2; plural=(n != 1);");
